"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.MediaItemImporter = void 0;

var _asyncSema = require("async-sema");

var _fileType = _interopRequireDefault(require("file-type"));

var _gatsbySourceFilesystem = require("gatsby-source-filesystem");

var _CacheAdapterPersist = require("./CacheAdapter/CacheAdapterPersist");

class MediaItemImporter {
  constructor({
    batchSize,
    args,
    cache
  }) {
    this.batchSize = void 0;
    this.args = void 0;
    this.cache = void 0;
    this.batchSize = batchSize !== null && batchSize !== void 0 ? batchSize : 10;
    this.args = args;
    this.cache = cache;
  }

  async process(mediaItems) {
    const progress = this.args.reporter.createProgress('wordpress-graphql: import media items', mediaItems.length, 0);
    progress.start();
    const sema = new _asyncSema.Sema(this.batchSize, {
      capacity: mediaItems.length
    });
    const fileNodes = await Promise.all(mediaItems.map(async mediaItem => {
      await sema.acquire();
      const fileNode = await this.importMediaItem(mediaItem);

      if (!fileNode) {
        sema.release();
        return null;
      }

      mediaItem.data.file = fileNode.id;
      progress.tick();
      sema.release();
      return fileNode;
    }));
    progress.done();
    return fileNodes.filter(Boolean);
  }

  async importMediaItem(mediaItem) {
    var _result$ext;

    const {
      cache,
      store,
      reporter,
      createNodeId,
      actions: {
        createNode
      }
    } = this.args;

    if (!mediaItem.sourceUrl) {
      return null;
    }

    const name = mediaItem.id;

    if (!(this.cache.adapter instanceof _CacheAdapterPersist.CacheAdapterPersist)) {
      return (0, _gatsbySourceFilesystem.createRemoteFileNode)({
        url: encodeURI(mediaItem.sourceUrl),
        name,
        cache,
        store,
        reporter,
        createNode,
        createNodeId,
        parentNodeId: mediaItem.id
      });
    }

    const buffer = await this.cache.adapter.file(mediaItem.sourceUrl);
    const result = await _fileType.default.fromBuffer(buffer);

    if (!result) {
      return null;
    }

    const ext = (_result$ext = result === null || result === void 0 ? void 0 : result.ext) !== null && _result$ext !== void 0 ? _result$ext : 'jpg';
    return (0, _gatsbySourceFilesystem.createFileNodeFromBuffer)({
      buffer,
      store,
      cache,
      createNode,
      createNodeId,
      parentNodeId: mediaItem.id,
      ext: `.${ext}`,
      name
    });
  }

}

exports.MediaItemImporter = MediaItemImporter;
//# sourceMappingURL=MediaItemImporter.js.map