"use strict";

exports.__esModule = true;
exports.sourceNodes = sourceNodes;
exports.CacheAdapterMap = void 0;

var _Cache = require("./lib/Cache");

var _CacheAdapterGatsby = require("./lib/CacheAdapter/CacheAdapterGatsby");

var _CacheAdapterPersist = require("./lib/CacheAdapter/CacheAdapterPersist");

var _MediaItemImporter = require("./lib/MediaItemImporter");

var _WordpressClient = require("./lib/WordpressClient");

var _WordpressCategory = require("./Models/WordpressCategory");

var _WordpressMediaItem = require("./Models/WordpressMediaItem");

var _WordpressPage = require("./Models/WordpressPage");

var _WordpressPost = require("./Models/WordpressPost");

var _WordpressUser = require("./Models/WordpressUser");

var _content = require("./util/content");

const CacheAdapterMap = {
  'gatsby': _CacheAdapterGatsby.CacheAdapterGatsby,
  'persist': _CacheAdapterPersist.CacheAdapterPersist
};
exports.CacheAdapterMap = CacheAdapterMap;

async function sourceNodes(args, {
  host,
  authorization,
  cacheAdapter,
  perPage,
  cacheOnly,
  batchSize,
  transformContent,
  importResources
}) {
  const adapter = new CacheAdapterMap[cacheAdapter](args);
  const cache = new _Cache.Cache(adapter);
  const mediaItemImporter = new _MediaItemImporter.MediaItemImporter({
    args,
    cache,
    batchSize
  });
  const client = new _WordpressClient.WordpressClient({
    host,
    authorization,
    cache,
    args,
    perPage,
    cacheOnly
  });
  const context = {
    createNodeId: args.createNodeId,
    createNode: args.actions.createNode,
    createContentDigest: args.createContentDigest,
    transformContent
  }; // Retrieve Data

  const [posts, pages, users, categories, mediaItems] = await Promise.all([importResources.includes('post') ? client.getPosts().then(records => _WordpressPost.WordpressPost.map(records, context)) : [], importResources.includes('page') ? client.getPages().then(records => _WordpressPage.WordpressPage.map(records, context)) : [], importResources.includes('user') ? client.getUsers().then(records => _WordpressUser.WordpressUser.map(records, context)) : [], importResources.includes('category') ? client.getCategories().then(records => _WordpressCategory.WordpressCategory.map(records, context)) : [], importResources.includes('media') ? client.getMediaItems().then(records => _WordpressMediaItem.WordpressMediaItem.map(records, context)) : []]); // Filter Media Items

  (0, _content.filterMediaItems)(mediaItems, [...posts, ...pages]); // Link Users with Pages and Posts

  for (const user of users) {
    user.data.posts = posts.filter(({
      author
    }) => author === user.id).map(({
      id
    }) => id);
    user.data.pages = pages.filter(({
      author
    }) => author === user.id).map(({
      id
    }) => id);
  } // Link Categories with Posts


  for (const category of categories) {
    category.data.posts = posts.filter(({
      categories
    }) => categories.includes(category.id)).map(({
      id
    }) => id);
  } // Import Media Items


  await mediaItemImporter.process(mediaItems); // Build Content Nodes

  for (const model of [...posts, ...pages, ...users, ...categories, ...mediaItems]) {
    model.build();
  }
}
//# sourceMappingURL=sourceNodes.js.map