"use strict";

exports.__esModule = true;
exports.processContent = processContent;
exports.compareUrl = compareUrl;
exports.filterMediaItems = filterMediaItems;

var _unihtml = require("unihtml");

const compareUrlRegex = /(-[0-9]+x[0-9]+)?\.[a-z]+$/;

function processContent(html, transformContent) {
  const tree = (0, _unihtml.parse)(html);

  if (transformContent) {
    (0, _unihtml.transform)(tree, transformContent);
  }

  return tree;
}

function compareUrl(a, b) {
  return a.replace(compareUrlRegex, '') === b.replace(compareUrlRegex, '');
}

function filterMediaItems(mediaItems, records) {
  const allMediaItems = new Set();

  for (const record of records) {
    const matchedMediaItems = new Set();
    (0, _unihtml.transform)(record.content.tree, ({
      custom
    }) => {
      custom(node => node.type === 'element' && node.tagName === 'img', (node, index) => {
        if (index === null || !node.properties.src) {
          return;
        }

        const sourceUrl = node.properties.src.replace(compareUrlRegex, '');
        const matchedMediaItem = mediaItems.find(mediaItem => compareUrl(mediaItem.sourceUrl, sourceUrl));

        if (!matchedMediaItem || !matchedMediaItem.sourceUrl) {
          return;
        }

        node.properties.src = `mediaItem://${matchedMediaItem.id}`;
        matchedMediaItems.add(matchedMediaItem);
        allMediaItems.add(matchedMediaItem);
      });
    });
    const featuredImage = mediaItems.find(({
      id
    }) => id === record.featuredImage);

    if (featuredImage && featuredImage.sourceUrl) {
      allMediaItems.add(featuredImage);
    }

    record.content.mediaItems = Array.from(matchedMediaItems).map(({
      id
    }) => id);
    record.content.html = (0, _unihtml.stringify)(record.content.tree);
  }

  mediaItems.length = 0;
  mediaItems.push(...Array.from(allMediaItems));
}
//# sourceMappingURL=content.js.map